var webpack = require('webpack');
var LiveReloadPlugin = require('webpack-livereload-plugin');
var UglifyJSPlugin = require('uglifyjs-webpack-plugin');
var path = require('path');
var sourcePath = path.join(__dirname, 'src');
var entryPath = path.join(sourcePath, 'index.js');
var buildPath = path.join(__dirname, 'public', 'local', 'dist');
// plugins
var plugins = [
  new webpack.ProvidePlugin({
    $: 'jquery',
    jQuery: 'jquery',
    'window.jQuery': 'jquery',
    Popper: ['popper.js', 'default'],        
  }),
  new webpack.DefinePlugin({
    'process.env.NODE_ENV': JSON.stringify(process.env.NODE_ENV)
  })
];
if (process.env.NODE_ENV === 'production') {
  plugins.push(new UglifyJSPlugin());
} else {
  plugins.push(new LiveReloadPlugin());
}

// for FRON page
if (process.env.FRONT) {
  buildPath = path.join(__dirname, 'assets');
  sourcePath = path.join(__dirname, 'src', 'front');
  entryPath = path.join(sourcePath, 'index.js');
}

module.exports = {
  entry: entryPath,
  output: {
    path: buildPath,
    filename: 'bundle.js'
  },
  devServer: {
    contentBase: buildPath, 
    inline: true,
    port: 3030
  },
  module: {
    loaders: [{
      test: /\.js$/,
      exclude: /node_modules/,
      loader: 'babel-loader',
      query: {
        presets: ['stage-2', "react"]
      }
    },
    {
      test: /\.scss$/,
      exclude: /node_modules/,
      use: [{
        loader: "style-loader"
      }, {
        loader: "css-loader"
      }, {
        loader: "sass-loader"
      }]
    }]
  },
  resolve: {
    modules: ['node_modules', sourcePath]
  },
  plugins: plugins
}